# TL-GPRSM
The tool for Tlansfer Learning Gaussian Process Regression Surrogate Model
## Install
You can install TL-GPRSM from PyPi with pip.  
`pip install TL-GPRSM`  
or from github with pip.  
`pip install git+https://github.com/SaidaTaisei/TL-GPRSM`  

## Document
Document https://saidataisei.github.io/TL-GPRSM/

## Tutorials (how to use TL-GPRSM)
Tutorials are provided in jupyter notebook implementation.
Tutorial: https://github.com/SaidaTaisei/TL-GPRSM/tree/master/Tutorial

## Citation
```
@article{SAIDA2023107014,
title = {Transfer learning Gaussian process regression surrogate model with explainability for structural reliability analysis under variation in uncertainties},
journal = {Computers & Structures},
volume = {281},
pages = {107014},
year = {2023},
issn = {0045-7949},
doi = {https://doi.org/10.1016/j.compstruc.2023.107014},
url = {https://www.sciencedirect.com/science/article/pii/S0045794923000445},
author = {Taisei Saida and Mayuko Nishio}
}
```
